@@ -1,7 +1,5 @@
 use proc_macro2::{Span as Span2, TokenStream as TokenStream2};
-use syn::{
-    punctuated::Punctuated, token, token::Mut, Expr, ExprClosure, Generics, Ident, Lit, Path,
-};
+use syn::{punctuated::Punctuated, token, token::Mut, Expr, ExprClosure, Generics, Ident, Path};
 
 use crate::args::Args;
 
@@ -17,7 +15,6 @@ pub(super) struct Tracker {
 #[derive(Debug)]
 pub(super) enum PropertyType {
     Expr(Expr),
-    Value(Lit),
     Track(Tracker),
     Parent(Expr),
     Args(Args<Expr>),
